@@ -72,6 +72,11 @@ func (m *MockEC2) CreateSubnetWithId(request *ec2.CreateSubnetInput, id string)
 		VpcId:            request.VpcId,
 		CidrBlock:        request.CidrBlock,
 		AvailabilityZone: request.AvailabilityZone,
+		PrivateDnsNameOptionsOnLaunch: &ec2.PrivateDnsNameOptionsOnLaunch{
+			EnableResourceNameDnsAAAARecord: aws.Bool(false),
+			EnableResourceNameDnsARecord:    aws.Bool(false),
+			HostnameType:                    aws.String(ec2.HostnameTypeIpName),
+		},
 	}
 
 	if request.Ipv6CidrBlock != nil {
@@ -249,3 +254,17 @@ func (m *MockEC2) DeleteSubnetWithContext(aws.Context, *ec2.DeleteSubnetInput, .
 func (m *MockEC2) DeleteSubnetRequest(*ec2.DeleteSubnetInput) (*request.Request, *ec2.DeleteSubnetOutput) {
 	panic("Not implemented")
 }
+
+func (m *MockEC2) ModifySubnetAttribute(request *ec2.ModifySubnetAttributeInput) (*ec2.ModifySubnetAttributeOutput, error) {
+	subnet := m.subnets[*request.SubnetId]
+	if request.EnableResourceNameDnsAAAARecordOnLaunch != nil {
+		subnet.main.PrivateDnsNameOptionsOnLaunch.EnableResourceNameDnsAAAARecord = request.EnableResourceNameDnsAAAARecordOnLaunch.Value
+	}
+	if request.EnableResourceNameDnsARecordOnLaunch != nil {
+		subnet.main.PrivateDnsNameOptionsOnLaunch.EnableResourceNameDnsARecord = request.EnableResourceNameDnsARecordOnLaunch.Value
+	}
+	if request.PrivateDnsHostnameTypeOnLaunch != nil {
+		subnet.main.PrivateDnsNameOptionsOnLaunch.HostnameType = request.PrivateDnsHostnameTypeOnLaunch
+	}
+	return &ec2.ModifySubnetAttributeOutput{}, nil
+}
