@@ -210,7 +210,7 @@ func runLifecycleTest(h *testutils.IntegrationTestHarness, o *LifecycleTestOptio
 		if err != nil {
 			t.Fatalf("error getting cluster: %v", err)
 		}
-		clientset, err := factory.Clientset()
+		clientset, err := factory.KopsClient()
 		if err != nil {
 			t.Fatalf("error getting clientset: %v", err)
 		}
