@@ -21,9 +21,16 @@ import (
 	"net/url"
 	"strings"
 
+	certmanager "github.com/cert-manager/cert-manager/pkg/client/clientset/versioned"
 	"k8s.io/apimachinery/pkg/util/validation/field"
+	"k8s.io/cli-runtime/pkg/genericclioptions"
+	"k8s.io/client-go/dynamic"
+	"k8s.io/client-go/kubernetes"
+	"k8s.io/client-go/rest"
+	"k8s.io/client-go/restmapper"
 	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/klog/v2"
+	channelscmd "k8s.io/kops/channels/pkg/cmd"
 	gceacls "k8s.io/kops/pkg/acls/gce"
 	s3acls "k8s.io/kops/pkg/acls/s3"
 	kopsclient "k8s.io/kops/pkg/client/clientset_generated/clientset"
@@ -38,8 +45,16 @@ type FactoryOptions struct {
 }
 
 type Factory struct {
-	options   *FactoryOptions
-	clientset simple.Clientset
+	ConfigFlags genericclioptions.ConfigFlags
+	options     *FactoryOptions
+	clientset   simple.Clientset
+
+	kubernetesClient  kubernetes.Interface
+	certManagerClient certmanager.Interface
+
+	cachedRESTConfig *rest.Config
+	dynamicClient    dynamic.Interface
+	restMapper       *restmapper.DeferredDiscoveryRESTMapper
 }
 
 func NewFactory(options *FactoryOptions) *Factory {
@@ -62,7 +77,7 @@ For example, a valid value follows the format s3://<bucket>.
 Trailing slash will be trimmed.`
 )
 
-func (f *Factory) Clientset() (simple.Clientset, error) {
+func (f *Factory) KopsClient() (simple.Clientset, error) {
 	if f.clientset == nil {
 		registryPath := f.options.RegistryPath
 		klog.V(2).Infof("state store %s", registryPath)
@@ -129,3 +144,80 @@ func (f *Factory) Clientset() (simple.Clientset, error) {
 func (f *Factory) KopsStateStore() string {
 	return f.options.RegistryPath
 }
+
+var _ channelscmd.Factory = &Factory{}
+
+func (f *Factory) restConfig() (*rest.Config, error) {
+	if f.cachedRESTConfig == nil {
+		restConfig, err := f.ConfigFlags.ToRESTConfig()
+		if err != nil {
+			return nil, fmt.Errorf("cannot load kubecfg settings: %w", err)
+		}
+		restConfig.UserAgent = "kops"
+		f.cachedRESTConfig = restConfig
+	}
+	return f.cachedRESTConfig, nil
+}
+
+func (f *Factory) KubernetesClient() (kubernetes.Interface, error) {
+	if f.kubernetesClient == nil {
+		restConfig, err := f.restConfig()
+		if err != nil {
+			return nil, err
+		}
+		k8sClient, err := kubernetes.NewForConfig(restConfig)
+		if err != nil {
+			return nil, fmt.Errorf("cannot build kube client: %w", err)
+		}
+		f.kubernetesClient = k8sClient
+	}
+
+	return f.kubernetesClient, nil
+}
+
+func (f *Factory) DynamicClient() (dynamic.Interface, error) {
+	if f.dynamicClient == nil {
+		restConfig, err := f.restConfig()
+		if err != nil {
+			return nil, fmt.Errorf("cannot load kubecfg settings: %w", err)
+		}
+		dynamicClient, err := dynamic.NewForConfig(restConfig)
+		if err != nil {
+			return nil, fmt.Errorf("cannot build dynamicClient client: %v", err)
+		}
+		f.dynamicClient = dynamicClient
+	}
+
+	return f.dynamicClient, nil
+}
+
+func (f *Factory) CertManagerClient() (certmanager.Interface, error) {
+	if f.certManagerClient == nil {
+		restConfig, err := f.restConfig()
+		if err != nil {
+			return nil, err
+		}
+		certManagerClient, err := certmanager.NewForConfig(restConfig)
+		if err != nil {
+			return nil, fmt.Errorf("cannot build kube client: %v", err)
+		}
+		f.certManagerClient = certManagerClient
+	}
+
+	return f.certManagerClient, nil
+}
+
+func (f *Factory) RESTMapper() (*restmapper.DeferredDiscoveryRESTMapper, error) {
+	if f.restMapper == nil {
+		discoveryClient, err := f.ConfigFlags.ToDiscoveryClient()
+		if err != nil {
+			return nil, err
+		}
+
+		restMapper := restmapper.NewDeferredDiscoveryRESTMapper(discoveryClient)
+
+		f.restMapper = restMapper
+	}
+
+	return f.restMapper, nil
+}
