@@ -109,12 +109,10 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 
 	// Set the signing key if we're using Service Account Token VolumeProjection
 	if kubeAPIServer.ServiceAccountSigningKeyFile == nil {
-		if fi.StringValue(kubeAPIServer.ServiceAccountIssuer) != "" {
-			s := filepath.Join(pathSrvKAPI, "service-account.key")
-			kubeAPIServer.ServiceAccountSigningKeyFile = &s
-			if err := b.BuildPrivateKeyTask(c, "service-account", pathSrvKAPI, "service-account", nil, nil); err != nil {
-				return err
-			}
+		s := filepath.Join(pathSrvKAPI, "service-account.key")
+		kubeAPIServer.ServiceAccountSigningKeyFile = &s
+		if err := b.BuildPrivateKeyTask(c, "service-account", pathSrvKAPI, "service-account", nil, nil); err != nil {
+			return err
 		}
 	}
 
@@ -607,7 +605,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	}
 
 	image := kubeAPIServer.Image
-	if components.IsBaseURL(b.Cluster.Spec.KubernetesVersion) {
+	if components.IsBaseURL(b.Cluster.Spec.KubernetesVersion) && b.IsKubernetesLT("1.25") {
 		image = strings.Replace(image, "registry.k8s.io", "k8s.gcr.io", 1)
 	}
 	if b.Architecture != architectures.ArchitectureAmd64 {
