@@ -32,109 +32,100 @@ func Test_KubeAPIServer_BuildFlags(t *testing.T) {
 	}{
 		{
 			kops.KubeAPIServerConfig{},
-			"--insecure-port=0 --secure-port=0",
+			"--secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				SecurePort: 443,
 			},
-			"--insecure-port=0 --secure-port=443",
+			"--secure-port=443",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				MaxRequestsInflight: 1000,
 			},
-			"--insecure-port=0 --max-requests-inflight=1000 --secure-port=0",
+			"--max-requests-inflight=1000 --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				MaxMutatingRequestsInflight: 900,
 			},
-			"--insecure-port=0 --max-mutating-requests-inflight=900 --secure-port=0",
+			"--max-mutating-requests-inflight=900 --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
-				InsecurePort: 8080,
-				SecurePort:   443,
+				SecurePort: 443,
 			},
-			"--insecure-port=8080 --secure-port=443",
+			"--secure-port=443",
 		},
 		{
 			kops.KubeAPIServerConfig{
-				InsecurePort:        8080,
 				SecurePort:          443,
 				MaxRequestsInflight: 1000,
 			},
-			"--insecure-port=8080 --max-requests-inflight=1000 --secure-port=443",
+			"--max-requests-inflight=1000 --secure-port=443",
 		},
 		{
 			kops.KubeAPIServerConfig{
-				InsecurePort:                8080,
 				SecurePort:                  443,
 				MaxMutatingRequestsInflight: 900,
 			},
-			"--insecure-port=8080 --max-mutating-requests-inflight=900 --secure-port=443",
-		},
-		{
-			kops.KubeAPIServerConfig{
-				InsecurePort: 8080,
-			},
-			"--insecure-port=8080 --secure-port=0",
+			"--max-mutating-requests-inflight=900 --secure-port=443",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				ServiceNodePortRange: "30000-33000",
 			},
-			"--insecure-port=0 --secure-port=0 --service-node-port-range=30000-33000",
+			"--secure-port=0 --service-node-port-range=30000-33000",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				ExperimentalEncryptionProviderConfig: fi.String("/srv/kubernetes/encryptionconfig.yaml"),
 			},
-			"--experimental-encryption-provider-config=/srv/kubernetes/encryptionconfig.yaml --insecure-port=0 --secure-port=0",
+			"--experimental-encryption-provider-config=/srv/kubernetes/encryptionconfig.yaml --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				EncryptionProviderConfig: fi.String("/srv/kubernetes/encryptionconfig.yaml"),
 			},
-			"--encryption-provider-config=/srv/kubernetes/encryptionconfig.yaml --insecure-port=0 --secure-port=0",
+			"--encryption-provider-config=/srv/kubernetes/encryptionconfig.yaml --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				TargetRamMB: 320,
 			},
-			"--insecure-port=0 --secure-port=0 --target-ram-mb=320",
+			"--secure-port=0 --target-ram-mb=320",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				AuditDynamicConfiguration: &[]bool{true}[0],
 				ServiceAccountKeyFile:     []string{"/srv/kubernetes/server.key", "/srv/kubernetes/service-account.key"},
 			},
-			"--audit-dynamic-configuration=true --insecure-port=0 --secure-port=0 --service-account-key-file=/srv/kubernetes/server.key --service-account-key-file=/srv/kubernetes/service-account.key",
+			"--audit-dynamic-configuration=true --secure-port=0 --service-account-key-file=/srv/kubernetes/server.key --service-account-key-file=/srv/kubernetes/service-account.key",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				AuditDynamicConfiguration: &[]bool{false}[0],
 			},
-			"--audit-dynamic-configuration=false --insecure-port=0 --secure-port=0",
+			"--audit-dynamic-configuration=false --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				AuditDynamicConfiguration: &[]bool{true}[0],
 			},
-			"--audit-dynamic-configuration=true --insecure-port=0 --secure-port=0",
+			"--audit-dynamic-configuration=true --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				EnableProfiling: &[]bool{false}[0],
 			},
-			"--insecure-port=0 --profiling=false --secure-port=0",
+			"--profiling=false --secure-port=0",
 		},
 		{
 			kops.KubeAPIServerConfig{
 				ClientCAFile: "client-ca.crt",
 			},
-			"--client-ca-file=client-ca.crt --insecure-port=0 --secure-port=0",
+			"--client-ca-file=client-ca.crt --secure-port=0",
 		},
 	}
 
