@@ -125,15 +125,7 @@ func (b *SysctlBuilder) Build(c *fi.ModelBuilderContext) error {
 		)
 	}
 
-	// Running Flannel on CentOS7 / rhel7 needs custom settings
-	if b.Cluster.Spec.Networking.Flannel != nil {
-		proxyMode := b.Cluster.Spec.KubeProxy.ProxyMode
-		if proxyMode == "" {
-			proxyMode = "iptables"
-		}
-	}
-
-	if b.Cluster.Spec.CloudProvider == string(kops.CloudProviderAWS) {
+	if b.CloudProvider == kops.CloudProviderAWS {
 		sysctls = append(sysctls,
 			"# AWS settings",
 			"",
@@ -184,13 +176,21 @@ func (b *SysctlBuilder) Build(c *fi.ModelBuilderContext) error {
 			"")
 	}
 
+	if b.Cluster.Spec.Networking.Cilium != nil {
+		sysctls = append(sysctls,
+			"# Depending on systemd version, cloud and distro, rp_filters may be enabled.",
+			"# Cilium requires this to be disabled. See https://github.com/cilium/cilium/issues/10645",
+			"net.ipv4.conf.all.rp_filter=0",
+			"")
+	}
+
 	if params := b.NodeupConfig.SysctlParameters; len(params) > 0 {
 		sysctls = append(sysctls,
 			"# Custom sysctl parameters from instance group spec",
 			"")
 		for _, param := range params {
 			if !strings.ContainsRune(param, '=') {
-				return fmt.Errorf("Invalid SysctlParameter: expected %q to contain '='", param)
+				return fmt.Errorf("invalid SysctlParameter: expected %q to contain '='", param)
 			}
 			sysctls = append(sysctls, param)
 		}
@@ -202,7 +202,7 @@ func (b *SysctlBuilder) Build(c *fi.ModelBuilderContext) error {
 			"")
 		for _, param := range params {
 			if !strings.ContainsRune(param, '=') {
-				return fmt.Errorf("Invalid SysctlParameter: expected %q to contain '='", param)
+				return fmt.Errorf("invalid SysctlParameter: expected %q to contain '='", param)
 			}
 			sysctls = append(sysctls, param)
 		}
