@@ -720,9 +720,9 @@ type KubeSchedulerConfig struct {
 	// as outlined: https://kubernetes.io/docs/concepts/storage/storage-limits/
 	MaxPersistentVolumes *int32 `json:"maxPersistentVolumes,omitempty"`
 	// Qps sets the maximum qps to send to apiserver after the burst quota is exhausted
-	Qps *resource.Quantity `json:"qps,omitempty" configfile:"ClientConnection.QPS"`
+	Qps *resource.Quantity `json:"qps,omitempty" configfile:"ClientConnection.QPS" config:"clientConnection.qps,omitempty"`
 	// Burst sets the maximum qps to send to apiserver after the burst quota is exhausted
-	Burst int32 `json:"burst,omitempty" configfile:"ClientConnection.Burst"`
+	Burst int32 `json:"burst,omitempty" configfile:"ClientConnection.Burst" config:"clientConnection.burst,omitempty"`
 	// AuthenticationKubeconfig is the path to an Authentication Kubeconfig
 	AuthenticationKubeconfig string `json:"authenticationKubeconfig,omitempty" flag:"authentication-kubeconfig"`
 	// AuthorizationKubeconfig is the path to an Authorization Kubeconfig
@@ -883,6 +883,10 @@ type AWSEBSCSIDriver struct {
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
 
+	// Managed controls if aws-ebs-csi-driver is manged and deployed by kOps.
+	// The deployment of aws-ebs-csi-driver is skipped if this is set to false.
+	Managed *bool `json:"managed,omitempty"`
+
 	// Version is the container image tag used.
 	// Default: The latest stable release which is compatible with your Kubernetes version
 	Version *string `json:"version,omitempty"`
@@ -941,6 +945,8 @@ type NodeTerminationHandlerConfig struct {
 	ExcludeFromLoadBalancers *bool `json:"excludeFromLoadBalancers,omitempty"`
 
 	// ManagedASGTag is the tag used to determine which nodes NTH can take action on
+	// This field has kept its name even though it now maps to the --managed-tag flag due to keeping the API stable.
+	// Node termination handler does no longer check the ASG for this tag, but the actual EC2 instances.
 	ManagedASGTag *string `json:"managedASGTag,omitempty"`
 
 	// MemoryRequest of NodeTerminationHandler container.
@@ -1007,6 +1013,9 @@ type ClusterAutoscalerConfig struct {
 	// ScaleDownDelayAfterAdd determines the time after scale up that scale down evaluation resumes
 	// Default: 10m0s
 	ScaleDownDelayAfterAdd *string `json:"scaleDownDelayAfterAdd,omitempty"`
+	// CordonNodeBeforeTerminating should CA cordon nodes before terminating during downscale process
+	// Default: false
+	CordonNodeBeforeTerminating *bool `json:"cordonNodeBeforeTerminating,omitempty"`
 	// Image is the docker container used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
@@ -1057,6 +1066,9 @@ type CertManagerConfig struct {
 	// nameservers is a list of nameserver IP addresses to use instead of the pod defaults.
 	// Default: none
 	Nameservers []string `json:"nameservers,omitempty"`
+
+	// HostedZoneIDs is a list of route53 hostedzone IDs that cert-manager will be allowed to do dns-01 validation for
+	HostedZoneIDs []string `json:"hostedZoneIDs,omitempty"`
 }
 
 // AWSLoadBalancerControllerConfig determines the AWS LB controller configuration.
