@@ -880,6 +880,10 @@ type AWSEBSCSIDriver struct {
 	// Default: false
 	Enabled *bool `json:"enabled,omitempty"`
 
+	// Managed controls if aws-ebs-csi-driver is manged and deployed by kOps.
+	// The deployment of aws-ebs-csi-driver is skipped if this is set to false.
+	Managed *bool `json:"managed,omitempty"`
+
 	// Version is the container image tag used.
 	// Default: The latest stable release which is compatible with your Kubernetes version
 	Version *string `json:"version,omitempty"`
@@ -934,6 +938,8 @@ type NodeTerminationHandlerConfig struct {
 	EnableSQSTerminationDraining *bool `json:"enableSQSTerminationDraining,omitempty"`
 
 	// ManagedASGTag is the tag used to determine which nodes NTH can take action on
+	// This field has kept its name even though it now maps to the --managed-tag flag due to keeping the API stable.
+	// Node termination handler does no longer check the ASG for this tag, but the actual EC2 instances.
 	ManagedASGTag *string `json:"managedASGTag,omitempty"`
 
 	// ExcludeFromLoadBalancers makes node termination handler will mark for exclusion from load balancers before node are cordoned.
@@ -1004,6 +1010,9 @@ type ClusterAutoscalerConfig struct {
 	// ScaleDownDelayAfterAdd determines the time after scale up that scale down evaluation resumes
 	// Default: 10m0s
 	ScaleDownDelayAfterAdd *string `json:"scaleDownDelayAfterAdd,omitempty"`
+	// CordonNodeBeforeTerminating should CA cordon nodes before terminating during downscale process
+	// Default: false
+	CordonNodeBeforeTerminating *bool `json:"cordonNodeBeforeTerminating,omitempty"`
 	// Image is the docker container used.
 	// Default: the latest supported image for the specified kubernetes version.
 	Image *string `json:"image,omitempty"`
@@ -1054,6 +1063,9 @@ type CertManagerConfig struct {
 	// nameservers is a list of nameserver IP addresses to use instead of the pod defaults.
 	// Default: none
 	Nameservers []string `json:"nameservers,omitempty"`
+
+	// HostedZoneIDs is a list of route53 hostedzone IDs that cert-manager will be allowed to do dns-01 validation for
+	HostedZoneIDs []string `json:"hostedZoneIDs,omitempty"`
 }
 
 // AWSLoadBalancerControllerConfig determines the AWS LB controller configuration.
