@@ -87,8 +87,6 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 	if eccm.Image == "" {
 		// See https://us.gcr.io/k8s-artifacts-prod/provider-aws/cloud-controller-manager
 		switch b.KubernetesVersion.Minor {
-		case 19:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.19.0-alpha.1"
 		case 20:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.20.1"
 		case 21:
@@ -99,6 +97,8 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.2"
 		case 24:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.1"
+		case 25:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.25.0"
 		default:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.1"
 		}
