@@ -39,28 +39,27 @@ func (b *ClusterAutoscalerOptionsBuilder) BuildOptions(o interface{}) error {
 
 	if cas.Image == nil {
 
-		image := "registry.k8s.io/autoscaling/cluster-autoscaler:latest"
+		image := ""
 		v, err := util.ParseKubernetesVersion(clusterSpec.KubernetesVersion)
 		if err == nil {
 			switch v.Minor {
 			case 25:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.24.0"
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.25.0"
 			case 24:
 				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.24.0"
 			case 23:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.23.0"
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.23.1"
 			case 22:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.22.2"
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.22.3"
 			case 21:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.21.2"
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.21.3"
 			case 20:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.20.1"
-			case 19:
-				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.19.2"
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.20.3"
+			default:
+				image = "registry.k8s.io/autoscaling/cluster-autoscaler:v1.25.0"
 			}
 		}
 		cas.Image = fi.String(image)
-
 	}
 
 	if cas.Expander == nil {
