@@ -25,6 +25,7 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/model/iam"
 	"k8s.io/kops/pkg/pki"
+	"k8s.io/kops/pkg/truncate"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awstasks"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
@@ -154,7 +155,7 @@ func (b *KopsModelContext) IAMName(role kops.InstanceGroupRole) string {
 	default:
 		klog.Fatalf("unknown InstanceGroup Role: %q", role)
 	}
-	return awsup.TruncateString(rolename, awsup.TruncateStringOptions{MaxLength: iam.MaxLengthIAMRoleName, AlwaysAddHash: false})
+	return truncate.TruncateString(rolename, truncate.TruncateStringOptions{MaxLength: iam.MaxLengthIAMRoleName, AlwaysAddHash: false})
 }
 
 var roleNamRegExp = regexp.MustCompile(`([^/]+$)`)
