@@ -44,12 +44,14 @@ import (
 	"k8s.io/kops/pkg/client/simple"
 	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/featureflag"
+	"k8s.io/kops/pkg/kubemanifest"
 	"k8s.io/kops/pkg/model"
 	"k8s.io/kops/pkg/model/awsmodel"
 	"k8s.io/kops/pkg/model/azuremodel"
 	"k8s.io/kops/pkg/model/components"
 	"k8s.io/kops/pkg/model/components/etcdmanager"
 	"k8s.io/kops/pkg/model/components/kubeapiserver"
+	"k8s.io/kops/pkg/model/components/kubescheduler"
 	"k8s.io/kops/pkg/model/domodel"
 	"k8s.io/kops/pkg/model/gcemodel"
 	"k8s.io/kops/pkg/model/hetznermodel"
@@ -80,13 +82,17 @@ const (
 	starline = "*********************************************************************************"
 
 	// OldestSupportedKubernetesVersion is the oldest kubernetes version that is supported in kOps.
-	OldestSupportedKubernetesVersion = "1.19.0"
+	OldestSupportedKubernetesVersion = "1.20.0"
 	// OldestRecommendedKubernetesVersion is the oldest kubernetes version that is not deprecated in kOps.
-	OldestRecommendedKubernetesVersion = "1.21.0"
+	OldestRecommendedKubernetesVersion = "1.22.0"
 )
 
 // TerraformCloudProviders is the list of cloud providers with terraform target support
-var TerraformCloudProviders = []kops.CloudProviderID{kops.CloudProviderAWS, kops.CloudProviderGCE}
+var TerraformCloudProviders = []kops.CloudProviderID{
+	kops.CloudProviderAWS,
+	kops.CloudProviderGCE,
+	kops.CloudProviderHetzner,
+}
 
 type ApplyClusterCmd struct {
 	Cloud   fi.Cloud
@@ -144,6 +150,9 @@ type ApplyClusterCmd struct {
 	ImageAssets []*assets.ImageAsset
 	// FileAssets are the file assets we use (output).
 	FileAssets []*assets.FileAsset
+
+	// AdditionalObjects holds cluster-asssociated configuration objects, other than the Cluster and InstanceGroups.
+	AdditionalObjects kubemanifest.ObjectList
 }
 
 func (c *ApplyClusterCmd) Run(ctx context.Context) error {
@@ -171,6 +180,18 @@ func (c *ApplyClusterCmd) Run(ctx context.Context) error {
 		c.InstanceGroups = instanceGroups
 	}
 
+	if c.AdditionalObjects == nil {
+		additionalObjects, err := c.Clientset.AddonsFor(c.Cluster).List()
+		if err != nil {
+			return err
+		}
+		// We use the nil object to mean "uninitialized"
+		if additionalObjects == nil {
+			additionalObjects = []*kubemanifest.Object{}
+		}
+		c.AdditionalObjects = additionalObjects
+	}
+
 	for _, ig := range c.InstanceGroups {
 		// Try to guess the path for additional third party volume plugins in Flatcar
 		image := strings.ToLower(ig.Spec.Image)
@@ -392,8 +413,9 @@ func (c *ApplyClusterCmd) Run(ctx context.Context) error {
 	}
 
 	modelContext := &model.KopsModelContext{
-		IAMModelContext: iam.IAMModelContext{Cluster: cluster},
-		InstanceGroups:  c.InstanceGroups,
+		IAMModelContext:   iam.IAMModelContext{Cluster: cluster},
+		InstanceGroups:    c.InstanceGroups,
+		AdditionalObjects: c.AdditionalObjects,
 	}
 
 	switch cluster.Spec.GetCloudProvider() {
@@ -405,9 +427,7 @@ func (c *ApplyClusterCmd) Run(ctx context.Context) error {
 
 	case kops.CloudProviderHetzner:
 		{
-			if !featureflag.Hetzner.Enabled() {
-				return fmt.Errorf("Hetzner Cloud support is currently alpha, and is feature-gated.  export KOPS_FEATURE_FLAGS=Hetzner")
-			}
+			// Hetzner Cloud support is currently in beta
 		}
 
 	case kops.CloudProviderDO:
@@ -525,6 +545,11 @@ func (c *ApplyClusterCmd) Run(ctx context.Context) error {
 				KopsModelContext: modelContext,
 				Lifecycle:        clusterLifecycle,
 			},
+			&kubescheduler.KubeSchedulerBuilder{
+				AssetBuilder:     assetBuilder,
+				KopsModelContext: modelContext,
+				Lifecycle:        clusterLifecycle,
+			},
 			&etcdmanager.EtcdManagerBuilder{
 				AssetBuilder:     assetBuilder,
 				KopsModelContext: modelContext,
@@ -1112,7 +1137,7 @@ type nodeUpConfigBuilder struct {
 	channels                   []string
 	configBase                 vfs.Path
 	cluster                    *kops.Cluster
-	etcdManifests              map[kops.InstanceGroupRole][]string
+	etcdManifests              map[string][]string
 	images                     map[kops.InstanceGroupRole]map[architectures.Architecture][]*nodeup.Image
 	protokubeAsset             map[architectures.Architecture][]*mirrors.MirroredAsset
 	channelsAsset              map[architectures.Architecture][]*mirrors.MirroredAsset
@@ -1133,7 +1158,7 @@ func newNodeUpConfigBuilder(cluster *kops.Cluster, assetBuilder *assets.AssetBui
 		channels = append(channels, cluster.Spec.Addons[i].Manifest)
 	}
 
-	etcdManifests := map[kops.InstanceGroupRole][]string{}
+	etcdManifests := map[string][]string{}
 	images := map[kops.InstanceGroupRole]map[architectures.Architecture][]*nodeup.Image{}
 	protokubeAsset := map[architectures.Architecture][]*mirrors.MirroredAsset{}
 	channelsAsset := map[architectures.Architecture][]*mirrors.MirroredAsset{}
@@ -1243,8 +1268,11 @@ func newNodeUpConfigBuilder(cluster *kops.Cluster, assetBuilder *assets.AssetBui
 
 		if isMaster {
 			for _, etcdCluster := range cluster.Spec.EtcdClusters {
-				p := configBase.Join("manifests/etcd/" + etcdCluster.Name + ".yaml").Path()
-				etcdManifests[role] = append(etcdManifests[role], p)
+				for _, member := range etcdCluster.Members {
+					instanceGroup := fi.StringValue(member.InstanceGroup)
+					etcdManifest := fmt.Sprintf("manifests/etcd/%s-%s.yaml", etcdCluster.Name, instanceGroup)
+					etcdManifests[instanceGroup] = append(etcdManifests[instanceGroup], configBase.Join(etcdManifest).Path())
+				}
 			}
 		}
 	}
@@ -1336,9 +1364,7 @@ func (n *nodeUpConfigBuilder) BuildConfig(ig *kops.InstanceGroup, apiserverAddit
 					return nil, nil, err
 				}
 			}
-			if cluster.Spec.KubeAPIServer != nil && fi.StringValue(cluster.Spec.KubeAPIServer.ServiceAccountIssuer) != "" {
-				config.KeypairIDs["service-account"] = keysets["service-account"].Primary.Id
-			}
+			config.KeypairIDs["service-account"] = keysets["service-account"].Primary.Id
 
 			config.APIServerConfig.EncryptionConfigSecretHash = n.encryptionConfigSecretHash
 			serviceAccountPublicKeys, err := keysets["service-account"].ToPublicKeys()
@@ -1410,9 +1436,27 @@ func (n *nodeUpConfigBuilder) BuildConfig(ig *kops.InstanceGroup, apiserverAddit
 		})
 	}
 
+	for _, staticFile := range n.assetBuilder.StaticFiles {
+		match := false
+		for _, r := range staticFile.Roles {
+			if r == role {
+				match = true
+			}
+		}
+
+		if !match {
+			continue
+		}
+
+		config.FileAssets = append(config.FileAssets, kops.FileAssetSpec{
+			Content: staticFile.Content,
+			Path:    staticFile.Path,
+		})
+	}
+
 	config.Images = n.images[role]
 	config.Channels = n.channels
-	config.EtcdManifests = n.etcdManifests[role]
+	config.EtcdManifests = n.etcdManifests[ig.Name]
 
 	if ig.Spec.Containerd != nil || cluster.Spec.ContainerRuntime == "containerd" {
 		config.ContainerdConfig = n.buildContainerdConfig(ig)
