@@ -25,6 +25,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"k8s.io/klog/v2"
+
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
@@ -36,7 +37,7 @@ import (
 // CloudTagInstanceGroupRolePrefix is a cloud tag that defines the instance role
 const CloudTagInstanceGroupRolePrefix = "k8s.io/role/"
 
-// AutoscalingGroup provdes the definition for a autoscaling group in aws
+// AutoscalingGroup provides the definition for a autoscaling group in aws
 // +kops:fitask
 type AutoscalingGroup struct {
 	// Name is the name of the ASG
@@ -52,6 +53,8 @@ type AutoscalingGroup struct {
 	LaunchTemplate *LaunchTemplate
 	// LoadBalancers is a list of elastic load balancer names to add to the autoscaling group
 	LoadBalancers []*ClassicLoadBalancer
+	// MaxInstanceLifetime is the maximum amount of time, in seconds, that an instance can be in service.
+	MaxInstanceLifetime *int64
 	// MaxSize is the max number of nodes in asg
 	MaxSize *int64
 	// Metrics is a collection of metrics to monitor
@@ -60,6 +63,8 @@ type AutoscalingGroup struct {
 	MinSize *int64
 	// MixedInstanceOverrides is a collection of instance types to use with fleet policy
 	MixedInstanceOverrides []string
+	// InstanceRequirements is a list of requirements for any instance type we are willing to run in the EC2 fleet.
+	InstanceRequirements *InstanceRequirements
 	// MixedOnDemandAllocationStrategy is allocation strategy to use for on-demand instances
 	MixedOnDemandAllocationStrategy *string
 	// MixedOnDemandBase is percentage split of On-Demand Instances and Spot Instances for your
@@ -107,9 +112,17 @@ func (e *AutoscalingGroup) Find(c *fi.Context) (*AutoscalingGroup, error) {
 	}
 
 	actual := &AutoscalingGroup{
-		Name:    g.AutoScalingGroupName,
-		MaxSize: g.MaxSize,
-		MinSize: g.MinSize,
+		Name:                g.AutoScalingGroupName,
+		MaxSize:             g.MaxSize,
+		MinSize:             g.MinSize,
+		MaxInstanceLifetime: g.MaxInstanceLifetime,
+	}
+
+	// Use 0 as default value when api returns nil (same as model)
+	if g.MaxInstanceLifetime == nil {
+		actual.MaxInstanceLifetime = fi.Int64(0)
+	} else {
+		actual.MaxInstanceLifetime = g.MaxInstanceLifetime
 	}
 
 	actual.LoadBalancers = []*ClassicLoadBalancer{}
@@ -215,6 +228,10 @@ func (e *AutoscalingGroup) Find(c *fi.Context) (*AutoscalingGroup, error) {
 			actual.MixedSpotAllocationStrategy = mpd.SpotAllocationStrategy
 			actual.MixedSpotInstancePools = mpd.SpotInstancePools
 			actual.MixedSpotMaxPrice = mpd.SpotMaxPrice
+			// MixedSpotMaxPrice must be set to "" in order to unset.
+			if mpd.SpotMaxPrice == nil {
+				actual.MixedSpotMaxPrice = fi.String("")
+			}
 		}
 
 		if g.MixedInstancesPolicy.LaunchTemplate != nil {
@@ -231,6 +248,9 @@ func (e *AutoscalingGroup) Find(c *fi.Context) (*AutoscalingGroup, error) {
 		}
 	}
 
+	ir, _ := findInstanceRequirements(g)
+	actual.InstanceRequirements = ir
+
 	if subnetSlicesEqualIgnoreOrder(actual.Subnets, e.Subnets) {
 		actual.Subnets = e.Subnets
 	}
@@ -334,6 +354,13 @@ func (v *AutoscalingGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Autos
 			VPCZoneIdentifier:                fi.String(strings.Join(e.AutoscalingGroupSubnets(), ",")),
 		}
 
+		//On ASG creation 0 value is forbidden
+		if fi.Int64Value(e.MaxInstanceLifetime) == 0 {
+			request.MaxInstanceLifetime = nil
+		} else {
+			request.MaxInstanceLifetime = e.MaxInstanceLifetime
+		}
+
 		for _, k := range e.LoadBalancers {
 			if k.LoadBalancerName == nil {
 				lbDesc, err := t.Cloud.FindELBByNameTag(fi.StringValue(k.GetName()))
@@ -377,6 +404,9 @@ func (v *AutoscalingGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Autos
 				},
 				)
 			}
+			if e.InstanceRequirements != nil {
+				p.Overrides = append(p.Overrides, overridesFromInstanceRequirements(e.InstanceRequirements))
+			}
 		} else if e.LaunchTemplate != nil {
 			request.LaunchTemplate = &autoscaling.LaunchTemplateSpecification{
 				LaunchTemplateId: e.LaunchTemplate.ID,
@@ -471,7 +501,7 @@ func (v *AutoscalingGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Autos
 			setup(request).InstancesDistribution.SpotMaxPrice = e.MixedSpotMaxPrice
 			changes.MixedSpotMaxPrice = nil
 		}
-		if changes.MixedInstanceOverrides != nil {
+		if changes.MixedInstanceOverrides != nil || changes.InstanceRequirements != nil {
 			if setup(request).LaunchTemplate == nil {
 				setup(request).LaunchTemplate = &autoscaling.LaunchTemplate{
 					LaunchTemplateSpecification: &autoscaling.LaunchTemplateSpecification{
@@ -481,11 +511,20 @@ func (v *AutoscalingGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Autos
 				}
 			}
 
-			p := request.MixedInstancesPolicy.LaunchTemplate
-			for _, x := range changes.MixedInstanceOverrides {
-				p.Overrides = append(p.Overrides, &autoscaling.LaunchTemplateOverrides{InstanceType: fi.String(x)})
+			if changes.MixedInstanceOverrides != nil {
+				p := request.MixedInstancesPolicy.LaunchTemplate
+				for _, x := range changes.MixedInstanceOverrides {
+					p.Overrides = append(p.Overrides, &autoscaling.LaunchTemplateOverrides{InstanceType: fi.String(x)})
+				}
+				changes.MixedInstanceOverrides = nil
+			}
+
+			if changes.InstanceRequirements != nil {
+				p := request.MixedInstancesPolicy.LaunchTemplate
+
+				p.Overrides = append(p.Overrides, overridesFromInstanceRequirements(changes.InstanceRequirements))
+				changes.InstanceRequirements = nil
 			}
-			changes.MixedInstanceOverrides = nil
 		}
 
 		if changes.MinSize != nil {
@@ -501,6 +540,13 @@ func (v *AutoscalingGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Autos
 			changes.Subnets = nil
 		}
 
+		if changes.MaxInstanceLifetime != nil {
+			request.MaxInstanceLifetime = e.MaxInstanceLifetime
+			changes.MaxInstanceLifetime = nil
+		} else {
+			request.MaxInstanceLifetime = fi.Int64(0)
+		}
+
 		var updateTagsRequest *autoscaling.CreateOrUpdateTagsInput
 		var deleteTagsRequest *autoscaling.DeleteTagsInput
 		if changes.Tags != nil {
@@ -670,6 +716,9 @@ func (e *AutoscalingGroup) UseMixedInstancesPolicy() bool {
 	if e.MixedSpotMaxPrice != nil {
 		return true
 	}
+	if e.InstanceRequirements != nil {
+		return true
+	}
 
 	return false
 }
@@ -866,17 +915,19 @@ type terraformAutoscalingGroup struct {
 	InstanceProtection      *bool                                            `cty:"protect_from_scale_in"`
 	LoadBalancers           []*terraformWriter.Literal                       `cty:"load_balancers"`
 	TargetGroupARNs         []*terraformWriter.Literal                       `cty:"target_group_arns"`
+	MaxInstanceLifetime     *int64                                           `cty:"max_instance_lifetime"`
 }
 
 // RenderTerraform is responsible for rendering the terraform codebase
 func (_ *AutoscalingGroup) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *AutoscalingGroup) error {
 	tf := &terraformAutoscalingGroup{
-		Name:               e.Name,
-		MinSize:            e.MinSize,
-		MaxSize:            e.MaxSize,
-		MetricsGranularity: e.Granularity,
-		EnabledMetrics:     aws.StringSlice(e.Metrics),
-		InstanceProtection: e.InstanceProtection,
+		Name:                e.Name,
+		MinSize:             e.MinSize,
+		MaxSize:             e.MaxSize,
+		MetricsGranularity:  e.Granularity,
+		EnabledMetrics:      aws.StringSlice(e.Metrics),
+		InstanceProtection:  e.InstanceProtection,
+		MaxInstanceLifetime: e.MaxInstanceLifetime,
 	}
 
 	for _, s := range e.Subnets {
