@@ -45,6 +45,7 @@ type Route struct {
 	InternetGateway           *InternetGateway
 	NatGateway                *NatGateway
 	TransitGatewayID          *string
+	VPCPeeringConnectionID    *string
 }
 
 func (e *Route) Find(c *fi.Context) (*Route, error) {
@@ -100,6 +101,9 @@ func (e *Route) Find(c *fi.Context) (*Route, error) {
 			if r.TransitGatewayId != nil {
 				actual.TransitGatewayID = r.TransitGatewayId
 			}
+			if r.VpcPeeringConnectionId != nil {
+				actual.VPCPeeringConnectionID = r.VpcPeeringConnectionId
+			}
 
 			if aws.StringValue(r.State) == "blackhole" {
 				klog.V(2).Infof("found route is a blackhole route")
@@ -155,11 +159,14 @@ func (s *Route) CheckChanges(a, e, changes *Route) error {
 		if e.TransitGatewayID != nil {
 			targetCount++
 		}
+		if e.VPCPeeringConnectionID != nil {
+			targetCount++
+		}
 		if targetCount == 0 {
-			return fmt.Errorf("EgressOnlyInternetGateway, InternetGateway, Instance, NatGateway, or TransitGateway is required")
+			return fmt.Errorf("EgressOnlyInternetGateway, InternetGateway, Instance, NatGateway, TransitGateway, or VpcPeeringConnection is required")
 		}
 		if targetCount != 1 {
-			return fmt.Errorf("cannot set more than one EgressOnlyInternetGateway, InternetGateway, Instance, NatGateway, or TransitGateway")
+			return fmt.Errorf("cannot set more than one EgressOnlyInternetGateway, InternetGateway, Instance, NatGateway, TransitGateway, or VpcPeeringConnection")
 		}
 	}
 
@@ -189,7 +196,7 @@ func (_ *Route) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Route) error {
 			klog.Fatal("both CIDR and IPv6CIDR were unexpectedly nil")
 		}
 
-		if e.EgressOnlyInternetGateway == nil && e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil {
+		if e.EgressOnlyInternetGateway == nil && e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil && e.VPCPeeringConnectionID == nil {
 			return fmt.Errorf("missing target for route")
 		} else if e.EgressOnlyInternetGateway != nil {
 			request.EgressOnlyInternetGatewayId = checkNotNil(e.EgressOnlyInternetGateway.ID)
@@ -199,6 +206,8 @@ func (_ *Route) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Route) error {
 			request.NatGatewayId = checkNotNil(e.NatGateway.ID)
 		} else if e.TransitGatewayID != nil {
 			request.TransitGatewayId = e.TransitGatewayID
+		} else if e.VPCPeeringConnectionID != nil {
+			request.VpcPeeringConnectionId = e.VPCPeeringConnectionID
 		}
 
 		if e.Instance != nil {
@@ -233,7 +242,7 @@ func (_ *Route) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Route) error {
 			klog.Fatal("both CIDR and IPv6CIDR were unexpectedly nil")
 		}
 
-		if e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil {
+		if e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil && e.VPCPeeringConnectionID == nil {
 			return fmt.Errorf("missing target for route")
 		} else if e.InternetGateway != nil {
 			request.GatewayId = checkNotNil(e.InternetGateway.ID)
@@ -241,6 +250,8 @@ func (_ *Route) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Route) error {
 			request.NatGatewayId = checkNotNil(e.NatGateway.ID)
 		} else if e.TransitGatewayID != nil {
 			request.TransitGatewayId = e.TransitGatewayID
+		} else if e.VPCPeeringConnectionID != nil {
+			request.VpcPeeringConnectionId = e.VPCPeeringConnectionID
 		}
 
 		if e.Instance != nil {
@@ -279,6 +290,7 @@ type terraformRoute struct {
 	NATGatewayID                *terraformWriter.Literal `cty:"nat_gateway_id"`
 	TransitGatewayID            *string                  `cty:"transit_gateway_id"`
 	InstanceID                  *terraformWriter.Literal `cty:"instance_id"`
+	VPCPeeringConnectionID      *string                  `cty:"vpc_peering_connection_id"`
 }
 
 func (_ *Route) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Route) error {
@@ -288,7 +300,7 @@ func (_ *Route) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Rou
 		IPv6CIDR:     e.IPv6CIDR,
 	}
 
-	if e.EgressOnlyInternetGateway == nil && e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil {
+	if e.EgressOnlyInternetGateway == nil && e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil && e.VPCPeeringConnectionID == nil {
 		return fmt.Errorf("missing target for route")
 	} else if e.EgressOnlyInternetGateway != nil {
 		tf.EgressOnlyInternetGatewayID = e.EgressOnlyInternetGateway.TerraformLink()
@@ -298,6 +310,8 @@ func (_ *Route) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Rou
 		tf.NATGatewayID = e.NatGateway.TerraformLink()
 	} else if e.TransitGatewayID != nil {
 		tf.TransitGatewayID = e.TransitGatewayID
+	} else if e.VPCPeeringConnectionID != nil {
+		tf.VPCPeeringConnectionID = e.VPCPeeringConnectionID
 	}
 
 	if e.Instance != nil {
@@ -311,13 +325,14 @@ func (_ *Route) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Rou
 }
 
 type cloudformationRoute struct {
-	RouteTableID      *cloudformation.Literal `json:"RouteTableId"`
-	CIDR              *string                 `json:"DestinationCidrBlock,omitempty"`
-	IPv6CIDR          *string                 `json:"DestinationIpv6CidrBlock,omitempty"`
-	InternetGatewayID *cloudformation.Literal `json:"GatewayId,omitempty"`
-	NATGatewayID      *cloudformation.Literal `json:"NatGatewayId,omitempty"`
-	TransitGatewayID  *string                 `json:"TransitGatewayId,omitempty"`
-	InstanceID        *cloudformation.Literal `json:"InstanceId,omitempty"`
+	RouteTableID           *cloudformation.Literal `json:"RouteTableId"`
+	CIDR                   *string                 `json:"DestinationCidrBlock,omitempty"`
+	IPv6CIDR               *string                 `json:"DestinationIpv6CidrBlock,omitempty"`
+	InternetGatewayID      *cloudformation.Literal `json:"GatewayId,omitempty"`
+	NATGatewayID           *cloudformation.Literal `json:"NatGatewayId,omitempty"`
+	TransitGatewayID       *string                 `json:"TransitGatewayId,omitempty"`
+	InstanceID             *cloudformation.Literal `json:"InstanceId,omitempty"`
+	VPCPeeringConnectionID *string                 `json:"VpcPeeringConnectionId,omitempty"`
 }
 
 func (_ *Route) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *Route) error {
@@ -327,7 +342,7 @@ func (_ *Route) RenderCloudformation(t *cloudformation.CloudformationTarget, a,
 		IPv6CIDR:     e.IPv6CIDR,
 	}
 
-	if e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil {
+	if e.InternetGateway == nil && e.NatGateway == nil && e.TransitGatewayID == nil && e.VPCPeeringConnectionID == nil {
 		return fmt.Errorf("missing target for route")
 	} else if e.InternetGateway != nil {
 		tf.InternetGatewayID = e.InternetGateway.CloudformationLink()
@@ -335,6 +350,8 @@ func (_ *Route) RenderCloudformation(t *cloudformation.CloudformationTarget, a,
 		tf.NATGatewayID = e.NatGateway.CloudformationLink()
 	} else if e.TransitGatewayID != nil {
 		tf.TransitGatewayID = e.TransitGatewayID
+	} else if e.VPCPeeringConnectionID != nil {
+		tf.VPCPeeringConnectionID = e.VPCPeeringConnectionID
 	}
 
 	if e.Instance != nil {
