@@ -53,7 +53,7 @@ import (
 
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/sets"
-	k8s_aws "k8s.io/legacy-cloud-providers/aws"
+	k8s_aws "k8s.io/cloud-provider-aws/pkg/providers/v1"
 
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider"
 	dnsproviderroute53 "k8s.io/kops/dnsprovider/pkg/dnsprovider/providers/aws/route53"
@@ -693,7 +693,6 @@ func deregisterInstanceFromTargetGroup(c AWSCloud, targetGroupArn string, instan
 				Id: aws.String(instanceId),
 			}},
 		})
-
 		if err != nil {
 			return fmt.Errorf("error describing target health: %w", err)
 		}
@@ -868,7 +867,7 @@ func buildKarpenterGroup(c AWSCloud, cluster *kops.Cluster, ig *kops.InstanceGro
 		}
 	}
 
-	klog.Infof("found %d karpenter instances", len(instances))
+	klog.V(2).Infof("found %d karpenter instances", len(instances))
 
 	{
 		req := &ec2.DescribeInstancesInput{
@@ -892,7 +891,7 @@ func buildKarpenterGroup(c AWSCloud, cluster *kops.Cluster, ig *kops.InstanceGro
 			}
 		}
 	}
-	klog.Infof("found %d updated instances", len(updatedInstances))
+	klog.V(2).Infof("found %d updated instances", len(updatedInstances))
 
 	{
 		for _, instance := range instances {
