@@ -173,6 +173,12 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["HCLOUD_TOKEN"] = func() string {
 		return os.Getenv("HCLOUD_TOKEN")
 	}
+	dest["HCLOUD_NETWORK"] = func() string {
+		if cluster.Spec.NetworkID != "" {
+			return cluster.Spec.NetworkID
+		}
+		return cluster.Name
+	}
 
 	if featureflag.Spotinst.Enabled() {
 		if creds, err := spotinst.LoadCredentials(); err == nil {
@@ -335,6 +341,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 		return sc != nil && fi.BoolValue(sc.Enabled)
 	}
 
+	dest["IsKubernetesGTE"] = tf.IsKubernetesGTE
 	dest["IsKubernetesLT"] = tf.IsKubernetesLT
 
 	return nil
@@ -883,6 +890,7 @@ func karpenterInstanceTypes(cloud awsup.AWSCloud, ig kops.InstanceGroupSpec) ([]
 				VCpuCount:            &ec2.VCpuCountRangeRequest{},
 				MemoryMiB:            &ec2.MemoryMiBRequest{},
 				BurstablePerformance: fi.String("included"),
+				InstanceGenerations:  []*string{fi.String("current")},
 			}
 			cpu := instanceRequirements.CPU
 			if cpu != nil {
