@@ -21,8 +21,12 @@ import (
 	"reflect"
 	"testing"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/ec2"
+	"k8s.io/kops/cloudmock/aws/mockec2"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 )
 
 func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
@@ -35,7 +39,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "Default Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider:                  string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{},
 			}},
 			expectedArgv: []string{
@@ -49,7 +55,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 			desc: "Log Level Configuration",
 			cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
-					CloudProvider: string(kops.CloudProviderOpenstack),
+					CloudProvider: kops.CloudProviderSpec{
+						Openstack: &kops.OpenstackSpec{},
+					},
 					ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 						LogLevel: 3,
 					},
@@ -93,7 +101,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "k8s cluster name",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					ClusterName: "k8s",
 				},
@@ -109,7 +119,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "Default Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					Master: "127.0.0.1",
 				},
@@ -125,7 +137,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "Cluster-cidr Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					ClusterCIDR: "10.0.0.0/24",
 				},
@@ -141,7 +155,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "AllocateNodeCIDRs Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					AllocateNodeCIDRs: fi.Bool(true),
 				},
@@ -157,7 +173,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "ConfigureCloudRoutes Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					ConfigureCloudRoutes: fi.Bool(true),
 				},
@@ -173,7 +191,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "CIDRAllocatorType Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					CIDRAllocatorType: fi.String("RangeAllocator"),
 				},
@@ -189,7 +209,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "CIDRAllocatorType Configuration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					UseServiceAccountCredentials: fi.Bool(false),
 				},
@@ -204,7 +226,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "Leader Election",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					LeaderElection: &kops.LeaderElectionConfiguration{LeaderElect: fi.Bool(true)},
 				},
@@ -220,7 +244,9 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		{
 			desc: "Leader Migration",
 			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
-				CloudProvider: string(kops.CloudProviderOpenstack),
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
 				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
 					LeaderElection:        &kops.LeaderElectionConfiguration{LeaderElect: fi.Bool(true)},
 					EnableLeaderMigration: fi.Bool(true),
@@ -235,6 +261,24 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 				"--cloud-config=/etc/kubernetes/cloud.config",
 			},
 		},
+		{
+			desc: "Disable Controller",
+			cluster: &kops.Cluster{Spec: kops.ClusterSpec{
+				CloudProvider: kops.CloudProviderSpec{
+					Openstack: &kops.OpenstackSpec{},
+				},
+				ExternalCloudControllerManager: &kops.CloudControllerManagerConfig{
+					Controllers: []string{"*", "-nodeipam"},
+				},
+			}},
+			expectedArgv: []string{
+				"--controllers=*,-nodeipam",
+				"--v=2",
+				"--cloud-provider=openstack",
+				"--use-service-account-credentials=true",
+				"--cloud-config=/etc/kubernetes/cloud.config",
+			},
+		},
 	}
 	for _, testCase := range tests {
 		t.Run(testCase.desc, func(t *testing.T) {
@@ -251,3 +295,26 @@ func Test_TemplateFunctions_CloudControllerConfigArgv(t *testing.T) {
 		})
 	}
 }
+
+func Test_KarpenterInstanceTypes(t *testing.T) {
+	amiId := "ami-073c8c0760395aab8"
+	ec2Client := &mockec2.MockEC2{}
+	ec2Client.Images = append(ec2Client.Images, &ec2.Image{
+		CreationDate:   aws.String("2016-10-21T20:07:19.000Z"),
+		ImageId:        &amiId,
+		Name:           aws.String("focal"),
+		OwnerId:        aws.String(awsup.WellKnownAccountUbuntu),
+		RootDeviceName: aws.String("/dev/xvda"),
+		Architecture:   aws.String("x86_64"),
+	})
+	ig := kops.InstanceGroupSpec{
+		Image: amiId,
+	}
+	cloud := &awsup.MockAWSCloud{MockCloud: awsup.MockCloud{
+		MockEC2: ec2Client,
+	}}
+	_, err := karpenterInstanceTypes(cloud, ig)
+	if err != nil {
+		t.Errorf("failed to fetch instance types: %v", err)
+	}
+}
