@@ -33,32 +33,18 @@ func Test_BuildMirroredAsset(t *testing.T) {
 		hash     string
 		expected []string
 	}{
-		{
-			url: "https://artifacts.k8s.io/binaries/kops/%s/images/protokube-linux-amd64",
-			expected: []string{
-				"https://artifacts.k8s.io/binaries/kops/1.24.3/images/protokube-linux-amd64",
-				"https://github.com/kubernetes/kops/releases/download/v1.24.3/images-protokube-linux-amd64",
-			},
-		},
-		{
-			url: "https://artifacts.k8s.io/binaries/kops/%s/images/protokube-linux-arm64",
-			expected: []string{
-				"https://artifacts.k8s.io/binaries/kops/1.24.3/images/protokube-linux-arm64",
-				"https://github.com/kubernetes/kops/releases/download/v1.24.3/images-protokube-linux-arm64",
-			},
-		},
 		{
 			url: "https://artifacts.k8s.io/binaries/kops/%s/linux/amd64/nodeup",
 			expected: []string{
-				"https://artifacts.k8s.io/binaries/kops/1.24.3/linux/amd64/nodeup",
-				"https://github.com/kubernetes/kops/releases/download/v1.24.3/nodeup-linux-amd64",
+				"https://artifacts.k8s.io/binaries/kops/1.25.0/linux/amd64/nodeup",
+				"https://github.com/kubernetes/kops/releases/download/v1.25.0/nodeup-linux-amd64",
 			},
 		},
 		{
 			url: "https://artifacts.k8s.io/binaries/kops/%s/linux/arm64/nodeup",
 			expected: []string{
-				"https://artifacts.k8s.io/binaries/kops/1.24.3/linux/arm64/nodeup",
-				"https://github.com/kubernetes/kops/releases/download/v1.24.3/nodeup-linux-arm64",
+				"https://artifacts.k8s.io/binaries/kops/1.25.0/linux/arm64/nodeup",
+				"https://github.com/kubernetes/kops/releases/download/v1.25.0/nodeup-linux-arm64",
 			},
 		},
 	}
