@@ -20,7 +20,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path"
 	"sync"
@@ -58,7 +57,7 @@ func (p *FSPath) WriteFile(data io.ReadSeeker, acl ACL) error {
 		return fmt.Errorf("error creating directories %q: %v", dir, err)
 	}
 
-	f, err := ioutil.TempFile(dir, "tmp")
+	f, err := os.CreateTemp(dir, "tmp")
 	if err != nil {
 		return fmt.Errorf("error creating temp file in %q: %v", dir, err)
 	}
@@ -116,7 +115,7 @@ func (p *FSPath) CreateFile(data io.ReadSeeker, acl ACL) error {
 
 // ReadFile implements Path::ReadFile
 func (p *FSPath) ReadFile() ([]byte, error) {
-	file, err := ioutil.ReadFile(p.location)
+	file, err := os.ReadFile(p.location)
 	if errors.Is(err, syscall.ENOENT) {
 		err = os.ErrNotExist
 	}
@@ -135,7 +134,7 @@ func (p *FSPath) WriteTo(out io.Writer) (int64, error) {
 }
 
 func (p *FSPath) ReadDir() ([]Path, error) {
-	files, err := ioutil.ReadDir(p.location)
+	files, err := os.ReadDir(p.location)
 	if err != nil {
 		if os.IsNotExist(err) {
 			return nil, err
@@ -161,7 +160,7 @@ func (p *FSPath) ReadTree() ([]Path, error) {
 // readTree recursively finds files and adds them to dest
 // It excludes directories.
 func readTree(base string, dest *[]Path) error {
-	files, err := ioutil.ReadDir(base)
+	files, err := os.ReadDir(base)
 	if err != nil {
 		return err
 	}
